<template>
  <div>
    <el-upload
      v-show="!imgUrl"
      class="upload-demo"
      :action="upload"
      list-type="picture-card"
      :show-file-list="false"
      :auto-upload="true"
      :multiple="true"
      :limit="1"
      :headers="headers"
      :file-list="fileList"
      :on-success="success"
      :data="updata"
      :accept="accept"
      :disabled="disabled"
      :on-exceed="handleExceed"
    >
      <el-tooltip placement="right" effect="light">
        <div slot="content">
          附件格式支持：{{ accept }} <br />附件大小限制：单个文件不超过50MB
        </div>
        <i slot="default" class="el-icon-plus"></i>
      </el-tooltip>
    </el-upload>
    <div class="el-upload-list el-upload-list--picture-card" v-if="imgUrl">
      <div class="el-upload-list__item is-success">
        <img v-if="imgUrl" :src="imgUrl" width="100%" height="100%" />
        <label class="el-upload-list__item-status-label">
          <i class="el-icon-upload-success el-icon-check"></i>
        </label>
        <span class="el-upload-list__item-actions" style="border-radius: 6px">
          <span class="el-upload-list__item-delete">
            <i class="el-icon-delete" @click="handleRemove"></i>
          </span>
          <span class="el-upload-list__item-delete">
            <i
              class="el-icon-zoom-in"
              @click.stop="handlePictureCardPreview()"
            ></i>
          </span>
        </span>
      </div>
    </div>
    <el-dialog
      append-to-body
      :visible.sync="updialogVisible"
      :close-on-click-modal="false"
      :close-on-press-escape="false"
      title="附件预览"
    >
      <img width="100%" :src="dialogImageUrl" alt="" />
    </el-dialog>
  </div>
</template>

<script>
import {mapState} from 'vuex'
import basicData from '@/api/basicData.js'
import req from '@/request.js'
export default {
  props: {
    accept: {
      type: String
    },
    disabled: {
      type: Boolean
    },
    url: {
      type: String,
      default: ''
    }
  },
  data() {
    return {
      updata: {
        bizPath: 'car_photo'
      },
      dialogImageUrl: '',
      updialogVisible: false,
      fileList: this.fileList,
      // imgUrl: this.url,
      // disabled: false, //按钮禁用控制
    }
  },
  // watch: {
  //   url: function(newVal) {
  //     this.imgUrl = newVal
  //   }
  // },
  computed: mapState({
    deleteUrl: function() {
      return (
        window.context.yhxt +
        '/bizMigrantBuildersInformation/v1/updateMigrantWorkersInformation'
      )
    },
    headers: state => {
      return {Authorization: `Bearer ${state.login.currentUser.token}`}
    },
    upload: function() {
      return window.context.portal + '/bizAccessory/v1/minioUpload'
    },
    imgUrl: function () {
      return this.url
    }
  }),
  methods: {
    handleExceed(file, fileList) {
      if (file.length > this.limit) {
        this.$message.warning(`上传个数超过限制个数，最多上传1个！！！`)
      }
    },
    success(response, file, fileList) {
      console.log(response, file, fileList)
      this.imgUrl = response.value.url
      this.fileList = fileList
      this.$emit('imageUrl', response.value.url)
    },
    //删除事件
    handleRemove() {
      this.fileList = []
      this.imgUrl = ''
      this.$emit('imageUrl', '')
    },
    handlePictureCardPreview() {
      this.dialogImageUrl = this.imgUrl
      this.updialogVisible = true
    },
    handleDownload(file) {
      // console.log(file)
      if (file.id) {
        req
          .downloadGet(
            window.context.yhxt +
              `/bizAccessory/v1/minIoAllDownFile?bizPath=car_photo&ids=${file.id}`
          )
          .then(res => {
            if (res) {
              this.$message.success('下载成功')
            }
          })
      } else {
        this.$message.info('请先保存附件')
      }
      // this.$emit('downFile',file)
    }
  }
}
</script>

<style lang="scss" scoped>
.upload-demo {
    max-width: 570px;
    margin-top: 5px;
}
</style>
